@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.3.1"
+__version__ = "1.3.2"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -1115,7 +1115,7 @@ def _get_package_entry_str(
         if "subdirectory" in info:
             result += "&subdirectory={}".format(info["subdirectory"])
 
-        return "\n" + result
+        return result + "\n"
     if "path" in info:
         # Path formats we want to support:
         # - "file:///path/to/project"
